@@ -3,7 +3,7 @@ BEGIN {
   $DBIx::Class::KiokuDB::EntryProxy::AUTHORITY = 'cpan:NUFFIN';
 }
 BEGIN {
-  $DBIx::Class::KiokuDB::EntryProxy::VERSION = '1.19';
+  $DBIx::Class::KiokuDB::EntryProxy::VERSION = '1.20';
 }
 
 use strict;
@@ -50,3 +50,12 @@ DBIx::Class::KiokuDB::EntryProxy - A proxying result class for KiokuDB objects
 
 This class implements the necessary glue to properly inflate resultsets for
 L<KiokuDB> object into proper instances using L<KiokuDB>.
+
+=begin Pod::Coverage
+
+new
+inflate_result
+
+=end Pod::Coverage
+
+=cut
