@@ -3,7 +3,7 @@ BEGIN {
   $KiokuDB::TypeMap::Entry::DBIC::Row::AUTHORITY = 'cpan:NUFFIN';
 }
 BEGIN {
-  $KiokuDB::TypeMap::Entry::DBIC::Row::VERSION = '1.19';
+  $KiokuDB::TypeMap::Entry::DBIC::Row::VERSION = '1.20';
 }
 use Moose;
 
@@ -101,3 +101,11 @@ already present in the other tables.
 
 Looking up an object with such an ID is a dynamic lookup that delegates to the
 L<DBIx::Class::Schema> and resultsets.
+
+=begin Pod::Coverage
+
+compile
+
+=end Pod::Coverage
+
+=cut
